@@ -71,13 +71,14 @@ type IntegrationKitSpec struct {
 type IntegrationKitTraits struct {
 	// The builder trait is internally used to determine the best strategy to build and configure IntegrationKits.
 	Builder *trait.BuilderTrait `property:"builder" json:"builder,omitempty"`
+	// The Camel trait sets up Camel configuration.
+	Camel *trait.CamelTrait `property:"camel" json:"camel,omitempty"`
 	// The Quarkus trait configures the Quarkus runtime.
 	// It's enabled by default.
 	// NOTE: Compiling to a native executable, i.e. when using `package-type=native`, is only supported for kamelets, as well as YAML and XML integrations. It also requires at least 4GiB of memory, so the Pod running the native build, that is either the operator Pod, or the build Pod (depending on the build strategy configured for the platform), must have enough memory available.
 	Quarkus *trait.QuarkusTrait `property:"quarkus" json:"quarkus,omitempty"`
 	// The Registry trait sets up Maven to use the Image registry as a Maven repository.
 	Registry *trait.RegistryTrait `property:"registry" json:"registry,omitempty"`
-
 	// The collection of addon trait configurations
 	Addons map[string]AddonTrait `json:"addons,omitempty"`
 }
