@@ -22,17 +22,20 @@ import (
 	"path"
 
 	appsv1 "k8s.io/api/apps/v1"
-	"k8s.io/api/batch/v1beta1"
+	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/util/intstr"
+	"k8s.io/utils/pointer"
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/pkg/util"
 	"github.com/apache/camel-k/pkg/util/camel"
 	"github.com/apache/camel-k/pkg/util/defaults"
+	"github.com/apache/camel-k/pkg/util/digest"
 	"github.com/apache/camel-k/pkg/util/envvar"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 )
@@ -45,103 +48,28 @@ const (
 	containerTraitID         = "container"
 )
 
-// The Container trait can be used to configure properties of the container where the integration will run.
-//
-// It also provides configuration for Services associated to the container.
-//
-// +camel-k:trait=container
-// nolint: tagliatelle
 type containerTrait struct {
-	BaseTrait `property:",squash"`
-
-	Auto *bool `property:"auto" json:"auto,omitempty"`
-
-	// The minimum amount of CPU required.
-	RequestCPU string `property:"request-cpu" json:"requestCPU,omitempty"`
-	// The minimum amount of memory required.
-	RequestMemory string `property:"request-memory" json:"requestMemory,omitempty"`
-	// The maximum amount of CPU required.
-	LimitCPU string `property:"limit-cpu" json:"limitCPU,omitempty"`
-	// The maximum amount of memory required.
-	LimitMemory string `property:"limit-memory" json:"limitMemory,omitempty"`
-
-	// Can be used to enable/disable exposure via kubernetes Service.
-	Expose *bool `property:"expose" json:"expose,omitempty"`
-	// To configure a different port exposed by the container (default `8080`).
-	Port int `property:"port" json:"port,omitempty"`
-	// To configure a different port name for the port exposed by the container. It defaults to `http` only when the `expose` parameter is true.
-	PortName string `property:"port-name" json:"portName,omitempty"`
-	// To configure under which service port the container port is to be exposed (default `80`).
-	ServicePort int `property:"service-port" json:"servicePort,omitempty"`
-	// To configure under which service port name the container port is to be exposed (default `http`).
-	ServicePortName string `property:"service-port-name" json:"servicePortName,omitempty"`
-	// The main container name. It's named `integration` by default.
-	Name string `property:"name" json:"name,omitempty"`
-	// The main container image
-	Image string `property:"image" json:"image,omitempty"`
-	// The pull policy: Always|Never|IfNotPresent
-	ImagePullPolicy corev1.PullPolicy `property:"image-pull-policy" json:"imagePullPolicy,omitempty"`
-
-	// DeprecatedProbesEnabled enable/disable probes on the container (default `false`)
-	// Deprecated: replaced by the health trait.
-	DeprecatedProbesEnabled *bool `property:"probes-enabled" json:"probesEnabled,omitempty"`
-	// Scheme to use when connecting. Defaults to HTTP. Applies to the liveness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedLivenessScheme string `property:"liveness-scheme" json:"livenessScheme,omitempty"`
-	// Number of seconds after the container has started before liveness probes are initiated.
-	// Deprecated: replaced by the health trait.
-	DeprecatedLivenessInitialDelay int32 `property:"liveness-initial-delay" json:"livenessInitialDelay,omitempty"`
-	// Number of seconds after which the probe times out. Applies to the liveness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedLivenessTimeout int32 `property:"liveness-timeout" json:"livenessTimeout,omitempty"`
-	// How often to perform the probe. Applies to the liveness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedLivenessPeriod int32 `property:"liveness-period" json:"livenessPeriod,omitempty"`
-	// Minimum consecutive successes for the probe to be considered successful after having failed.
-	// Applies to the liveness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedLivenessSuccessThreshold int32 `property:"liveness-success-threshold" json:"livenessSuccessThreshold,omitempty"`
-	// Minimum consecutive failures for the probe to be considered failed after having succeeded.
-	// Applies to the liveness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedLivenessFailureThreshold int32 `property:"liveness-failure-threshold" json:"livenessFailureThreshold,omitempty"`
-	// Scheme to use when connecting. Defaults to HTTP. Applies to the readiness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedReadinessScheme string `property:"readiness-scheme" json:"readinessScheme,omitempty"`
-	// Number of seconds after the container has started before readiness probes are initiated.
-	// Deprecated: replaced by the health trait.
-	DeprecatedReadinessInitialDelay int32 `property:"readiness-initial-delay" json:"readinessInitialDelay,omitempty"`
-	// Number of seconds after which the probe times out. Applies to the readiness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedReadinessTimeout int32 `property:"readiness-timeout" json:"readinessTimeout,omitempty"`
-	// How often to perform the probe. Applies to the readiness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedReadinessPeriod int32 `property:"readiness-period" json:"readinessPeriod,omitempty"`
-	// Minimum consecutive successes for the probe to be considered successful after having failed.
-	// Applies to the readiness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedReadinessSuccessThreshold int32 `property:"readiness-success-threshold" json:"readinessSuccessThreshold,omitempty"`
-	// Minimum consecutive failures for the probe to be considered failed after having succeeded.
-	// Applies to the readiness probe.
-	// Deprecated: replaced by the health trait.
-	DeprecatedReadinessFailureThreshold int32 `property:"readiness-failure-threshold" json:"readinessFailureThreshold,omitempty"`
+	BaseTrait
+	traitv1.ContainerTrait `property:",squash"`
 }
 
 func newContainerTrait() Trait {
 	return &containerTrait{
-		BaseTrait:                 NewBaseTrait(containerTraitID, 1600),
-		Port:                      defaultContainerPort,
-		ServicePort:               defaultServicePort,
-		ServicePortName:           defaultContainerPortName,
-		Name:                      defaultContainerName,
-		DeprecatedProbesEnabled:   BoolP(false),
-		DeprecatedLivenessScheme:  string(corev1.URISchemeHTTP),
-		DeprecatedReadinessScheme: string(corev1.URISchemeHTTP),
+		BaseTrait: NewBaseTrait(containerTraitID, 1600),
+		ContainerTrait: traitv1.ContainerTrait{
+			Port:                      defaultContainerPort,
+			ServicePort:               defaultServicePort,
+			ServicePortName:           defaultContainerPortName,
+			Name:                      defaultContainerName,
+			DeprecatedProbesEnabled:   pointer.Bool(false),
+			DeprecatedLivenessScheme:  string(corev1.URISchemeHTTP),
+			DeprecatedReadinessScheme: string(corev1.URISchemeHTTP),
+		},
 	}
 }
 
 func (t *containerTrait) Configure(e *Environment) (bool, error) {
-	if IsFalse(t.Enabled) {
+	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
 		return false, nil
 	}
 
@@ -149,7 +77,7 @@ func (t *containerTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	if IsNilOrTrue(t.Auto) {
+	if pointer.BoolDeref(t.Auto, true) {
 		if t.Expose == nil {
 			e := e.Resources.GetServiceForIntegration(e.Integration) != nil
 			t.Expose = &e
@@ -201,15 +129,12 @@ func (t *containerTrait) configureImageIntegrationKit(e *Environment) error {
 			kubernetes.CamelCreatorLabelVersion:   e.Integration.ResourceVersion,
 		}
 
-		if kit.Annotations == nil {
-			kit.Annotations = make(map[string]string)
-		}
 		if v, ok := e.Integration.Annotations[v1.PlatformSelectorAnnotation]; ok {
-			kit.Annotations[v1.PlatformSelectorAnnotation] = v
+			v1.SetAnnotation(&kit.ObjectMeta, v1.PlatformSelectorAnnotation, v)
 		}
 		operatorID := defaults.OperatorID()
 		if operatorID != "" {
-			kit.Annotations[v1.OperatorIDAnnotation] = operatorID
+			kit.SetOperatorID(operatorID)
 		}
 
 		t.L.Infof("image %s", kit.Spec.Image)
@@ -239,7 +164,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 		envvar.SetVal(&container.Env, env.Name, env.Value)
 	}
 
-	envvar.SetVal(&container.Env, "CAMEL_K_DIGEST", e.Integration.Status.Digest)
+	envvar.SetVal(&container.Env, digest.IntegrationDigestEnvVar, e.Integration.Status.Digest)
 	envvar.SetVal(&container.Env, "CAMEL_K_CONF", path.Join(camel.BasePath, "application.properties"))
 	envvar.SetVal(&container.Env, "CAMEL_K_CONF_D", camel.ConfDPath)
 
@@ -251,7 +176,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 	}
 
 	t.configureResources(e, &container)
-	if IsTrue(t.Expose) {
+	if pointer.BoolDeref(t.Expose, false) {
 		t.configureService(e, &container)
 	}
 	t.configureCapabilities(e)
@@ -297,7 +222,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 	}
 
 	// CronJob
-	if err := e.Resources.VisitCronJobE(func(cron *v1beta1.CronJob) error {
+	if err := e.Resources.VisitCronJobE(func(cron *batchv1.CronJob) error {
 		for _, envVar := range e.EnvVars {
 			envvar.SetVar(&container.Env, envVar)
 		}
