@@ -23,10 +23,12 @@ import (
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/utils/pointer"
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/pkg/metadata"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 	"github.com/apache/camel-k/pkg/util/label"
@@ -43,48 +45,13 @@ const (
 	knativeServingMaxScaleAnnotation = "autoscaling.knative.dev/maxScale"
 	// Rollout annotation.
 	knativeServingRolloutDurationAnnotation = "serving.knative.dev/rolloutDuration"
+	// visibility label.
+	knativeServingVisibilityLabel = "networking.knative.dev/visibility"
 )
 
-// The Knative Service trait allows configuring options when running the Integration as a Knative service, instead of
-// a standard Kubernetes Deployment.
-//
-// Running an Integration as a Knative Service enables auto-scaling (and scaling-to-zero), but those features
-// are only relevant when the Camel route(s) use(s) an HTTP endpoint consumer.
-//
-// +camel-k:trait=knative-service.
 type knativeServiceTrait struct {
-	BaseTrait `property:",squash"`
-	// Configures the Knative autoscaling class property (e.g. to set `hpa.autoscaling.knative.dev` or `kpa.autoscaling.knative.dev` autoscaling).
-	//
-	// Refer to the Knative documentation for more information.
-	Class string `property:"autoscaling-class" json:"class,omitempty"`
-	// Configures the Knative autoscaling metric property (e.g. to set `concurrency` based or `cpu` based autoscaling).
-	//
-	// Refer to the Knative documentation for more information.
-	Metric string `property:"autoscaling-metric" json:"autoscalingMetric,omitempty"`
-	// Sets the allowed concurrency level or CPU percentage (depending on the autoscaling metric) for each Pod.
-	//
-	// Refer to the Knative documentation for more information.
-	Target *int `property:"autoscaling-target" json:"autoscalingTarget,omitempty"`
-	// The minimum number of Pods that should be running at any time for the integration. It's **zero** by default, meaning that
-	// the integration is scaled down to zero when not used for a configured amount of time.
-	//
-	// Refer to the Knative documentation for more information.
-	MinScale *int `property:"min-scale" json:"minScale,omitempty"`
-	// An upper bound for the number of Pods that can be running in parallel for the integration.
-	// Knative has its own cap value that depends on the installation.
-	//
-	// Refer to the Knative documentation for more information.
-	MaxScale *int `property:"max-scale" json:"maxScale,omitempty"`
-	// Enables to gradually shift traffic to the latest Revision and sets the rollout duration.
-	// It's disabled by default and must be expressed as a Golang `time.Duration` string representation,
-	// rounded to a second precision.
-	RolloutDuration string `property:"rollout-duration" json:"rolloutDuration,omitempty"`
-	// Automatically deploy the integration as Knative service when all conditions hold:
-	//
-	// * Integration is using the Knative profile
-	// * All routes are either starting from a HTTP based consumer or a passive consumer (e.g. `direct` is a passive consumer)
-	Auto *bool `property:"auto" json:"auto,omitempty"`
+	BaseTrait
+	traitv1.KnativeServiceTrait `property:",squash"`
 }
 
 var _ ControllerStrategySelector = &knativeServiceTrait{}
@@ -97,17 +64,19 @@ func newKnativeServiceTrait() Trait {
 
 // IsAllowedInProfile overrides default.
 func (t *knativeServiceTrait) IsAllowedInProfile(profile v1.TraitProfile) bool {
-	return profile == v1.TraitProfileKnative
+	return profile.Equal(v1.TraitProfileKnative)
 }
 
 func (t *knativeServiceTrait) Configure(e *Environment) (bool, error) {
-	if IsFalse(t.Enabled) {
-		e.Integration.Status.SetCondition(
-			v1.IntegrationConditionKnativeServiceAvailable,
-			corev1.ConditionFalse,
-			v1.IntegrationConditionKnativeServiceNotAvailableReason,
-			"explicitly disabled",
-		)
+	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
+		if e.Integration != nil {
+			e.Integration.Status.SetCondition(
+				v1.IntegrationConditionKnativeServiceAvailable,
+				corev1.ConditionFalse,
+				v1.IntegrationConditionKnativeServiceNotAvailableReason,
+				"explicitly disabled",
+			)
+		}
 
 		return false, nil
 	}
@@ -149,7 +118,7 @@ func (t *knativeServiceTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	if IsNilOrTrue(t.Auto) {
+	if pointer.BoolDeref(t.Auto, true) {
 		// Check the right value for minScale, as not all services are allowed to scale down to 0
 		if t.MinScale == nil {
 			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, t.Client, e.Integration, e.Resources)
@@ -257,17 +226,30 @@ func (t *knativeServiceTrait) getServiceFor(e *Environment) (*serving.Service, e
 		revisionAnnotations[knativeServingMaxScaleAnnotation] = strconv.Itoa(*t.MaxScale)
 	}
 
+	serviceLabels := map[string]string{
+		v1.IntegrationLabel: e.Integration.Name,
+		// Make sure the Eventing webhook will select the source resource,
+		// in order to inject the sink information.
+		// This is necessary for Knative environments, that are configured
+		// with SINK_BINDING_SELECTION_MODE=inclusion.
+		// See:
+		// - https://knative.dev/v1.3-docs/eventing/custom-event-source/sinkbinding/create-a-sinkbinding/#optional-choose-sinkbinding-namespace-selection-behavior
+		// - https://github.com/knative/operator/blob/release-1.2/docs/configuration.md#specsinkbindingselectionmode
+		"bindings.knative.dev/include": "true",
+	}
+	if t.Visibility != "" {
+		serviceLabels[knativeServingVisibilityLabel] = t.Visibility
+	}
+
 	svc := serving.Service{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "Service",
 			APIVersion: serving.SchemeGroupVersion.String(),
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      e.Integration.Name,
-			Namespace: e.Integration.Namespace,
-			Labels: map[string]string{
-				v1.IntegrationLabel: e.Integration.Name,
-			},
+			Name:        e.Integration.Name,
+			Namespace:   e.Integration.Namespace,
+			Labels:      serviceLabels,
 			Annotations: serviceAnnotations,
 		},
 		Spec: serving.ServiceSpec{
