@@ -18,13 +18,13 @@ limitations under the License.
 package trait
 
 import (
-	"context"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/utils/pointer"
 
 	eventingduckv1 "knative.dev/eventing/pkg/apis/duck/v1"
 	eventing "knative.dev/eventing/pkg/apis/eventing/v1"
@@ -35,6 +35,7 @@ import (
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	knativeapi "github.com/apache/camel-k/pkg/apis/camel/v1/knative"
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/pkg/client"
 	"github.com/apache/camel-k/pkg/util/camel"
 	"github.com/apache/camel-k/pkg/util/envvar"
@@ -46,7 +47,7 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
 	assert.Nil(t, err)
 
-	traitCatalog := NewCatalog(context.TODO(), nil)
+	traitCatalog := NewCatalog(nil)
 
 	environment := Environment{
 		CamelCatalog: catalog,
@@ -63,17 +64,19 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 				Profile:   v1.TraitProfileKnative,
 				Sources:   []v1.SourceSpec{},
 				Resources: []v1.ResourceSpec{},
-				Traits: map[string]v1.TraitSpec{
-					"knative": test.TraitSpecFromMap(t, map[string]interface{}{
-						"enabled":         true,
-						"auto":            false,
-						"channelSources":  []string{"channel-source-1"},
-						"channelSinks":    []string{"channel-sink-1"},
-						"endpointSources": []string{"endpoint-source-1"},
-						"endpointSinks":   []string{"endpoint-sink-1", "endpoint-sink-2"},
-						"eventSources":    []string{"knative:event"},
-						"eventSinks":      []string{"knative:event"},
-					}),
+				Traits: v1.Traits{
+					Knative: &traitv1.KnativeTrait{
+						Trait: traitv1.Trait{
+							Enabled: pointer.Bool(true),
+						},
+						Auto:            pointer.Bool(false),
+						ChannelSources:  []string{"channel-source-1"},
+						ChannelSinks:    []string{"channel-sink-1"},
+						EndpointSources: []string{"endpoint-source-1"},
+						EndpointSinks:   []string{"endpoint-sink-1", "endpoint-sink-2"},
+						EventSources:    []string{"knative:event"},
+						EventSinks:      []string{"knative:event"},
+					},
 				},
 			},
 		},
@@ -87,7 +90,7 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 				Cluster: v1.IntegrationPlatformClusterOpenShift,
 				Build: v1.IntegrationPlatformBuildSpec{
 					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
-					Registry:        v1.IntegrationPlatformRegistrySpec{Address: "registry"},
+					Registry:        v1.RegistrySpec{Address: "registry"},
 				},
 				Profile: v1.TraitProfileKnative,
 			},
@@ -101,12 +104,12 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 	c, err := NewFakeClient("ns")
 	assert.Nil(t, err)
 
-	tc := NewCatalog(context.TODO(), c)
+	tc := NewCatalog(c)
 
-	err = tc.configure(&environment)
+	err = tc.Configure(&environment)
 	assert.Nil(t, err)
 
-	tr := tc.GetTrait("knative").(*knativeTrait)
+	tr, _ := tc.GetTrait("knative").(*knativeTrait)
 	ok, err := tr.Configure(&environment)
 	assert.Nil(t, err)
 	assert.True(t, ok)
@@ -151,7 +154,7 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
 	assert.Nil(t, err)
 
-	traitCatalog := NewCatalog(context.TODO(), nil)
+	traitCatalog := NewCatalog(nil)
 
 	environment := Environment{
 		CamelCatalog: catalog,
@@ -189,10 +192,12 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 					},
 				},
 				Resources: []v1.ResourceSpec{},
-				Traits: map[string]v1.TraitSpec{
-					"knative": test.TraitSpecFromMap(t, map[string]interface{}{
-						"enabled": true,
-					}),
+				Traits: v1.Traits{
+					Knative: &traitv1.KnativeTrait{
+						Trait: traitv1.Trait{
+							Enabled: pointer.Bool(true),
+						},
+					},
 				},
 			},
 		},
@@ -206,7 +211,7 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 				Cluster: v1.IntegrationPlatformClusterOpenShift,
 				Build: v1.IntegrationPlatformBuildSpec{
 					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
-					Registry:        v1.IntegrationPlatformRegistrySpec{Address: "registry"},
+					Registry:        v1.RegistrySpec{Address: "registry"},
 				},
 				Profile: v1.TraitProfileKnative,
 			},
@@ -220,12 +225,12 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 	c, err := NewFakeClient("ns")
 	assert.Nil(t, err)
 
-	tc := NewCatalog(context.TODO(), c)
+	tc := NewCatalog(c)
 
-	err = tc.configure(&environment)
+	err = tc.Configure(&environment)
 	assert.Nil(t, err)
 
-	tr := tc.GetTrait("knative").(*knativeTrait)
+	tr, _ := tc.GetTrait("knative").(*knativeTrait)
 
 	ok, err := tr.Configure(&environment)
 	assert.Nil(t, err)
@@ -288,9 +293,9 @@ func TestKnativePlatformHttpConfig(t *testing.T) {
 			c, err := NewFakeClient("ns")
 			assert.Nil(t, err)
 
-			tc := NewCatalog(context.TODO(), c)
+			tc := NewCatalog(c)
 
-			err = tc.configure(&environment)
+			err = tc.Configure(&environment)
 			assert.Nil(t, err)
 
 			err = tc.apply(&environment)
@@ -335,9 +340,9 @@ func TestKnativePlatformHttpDependencies(t *testing.T) {
 			c, err := NewFakeClient("ns")
 			assert.Nil(t, err)
 
-			tc := NewCatalog(context.TODO(), c)
+			tc := NewCatalog(c)
 
-			err = tc.configure(&environment)
+			err = tc.Configure(&environment)
 			assert.Nil(t, err)
 
 			err = tc.apply(&environment)
@@ -350,10 +355,12 @@ func TestKnativePlatformHttpDependencies(t *testing.T) {
 }
 
 func NewFakeEnvironment(t *testing.T, source v1.SourceSpec) Environment {
+	t.Helper()
+
 	catalog, err := camel.DefaultCatalog()
 	assert.Nil(t, err)
 
-	traitCatalog := NewCatalog(context.TODO(), nil)
+	traitCatalog := NewCatalog(nil)
 
 	environment := Environment{
 		CamelCatalog: catalog,
@@ -372,10 +379,12 @@ func NewFakeEnvironment(t *testing.T, source v1.SourceSpec) Environment {
 					source,
 				},
 				Resources: []v1.ResourceSpec{},
-				Traits: map[string]v1.TraitSpec{
-					"knative": test.TraitSpecFromMap(t, map[string]interface{}{
-						"enabled": true,
-					}),
+				Traits: v1.Traits{
+					Knative: &traitv1.KnativeTrait{
+						Trait: traitv1.Trait{
+							Enabled: pointer.Bool(true),
+						},
+					},
 				},
 			},
 		},
@@ -389,7 +398,7 @@ func NewFakeEnvironment(t *testing.T, source v1.SourceSpec) Environment {
 				Cluster: v1.IntegrationPlatformClusterOpenShift,
 				Build: v1.IntegrationPlatformBuildSpec{
 					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
-					Registry:        v1.IntegrationPlatformRegistrySpec{Address: "registry"},
+					Registry:        v1.RegistrySpec{Address: "registry"},
 				},
 				Profile: v1.TraitProfileKnative,
 			},
