@@ -25,6 +25,7 @@ import (
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
+	"hash"
 	"io"
 	"path"
 	"sort"
@@ -37,6 +38,10 @@ import (
 	"github.com/apache/camel-k/pkg/util/dsl"
 )
 
+const (
+	IntegrationDigestEnvVar = "CAMEL_K_DIGEST"
+)
+
 // ComputeForIntegration a digest of the fields that are relevant for the deployment
 // Produces a digest that can be used as docker image tag.
 func ComputeForIntegration(integration *v1.Integration) (string, error) {
@@ -45,6 +50,12 @@ func ComputeForIntegration(integration *v1.Integration) (string, error) {
 	if _, err := hash.Write([]byte(integration.Status.Version)); err != nil {
 		return "", err
 	}
+
+	// Integration operator id is relevant
+	if _, err := hash.Write([]byte(v1.GetOperatorIDAnnotation(integration))); err != nil {
+		return "", err
+	}
+
 	// Integration Kit is relevant
 	if integration.Spec.IntegrationKit != nil {
 		if _, err := hash.Write([]byte(fmt.Sprintf("%s/%s", integration.Spec.IntegrationKit.Namespace, integration.Spec.IntegrationKit.Name))); err != nil {
@@ -98,27 +109,28 @@ func ComputeForIntegration(integration *v1.Integration) (string, error) {
 	}
 
 	// Integration traits
-	for _, name := range sortedTraitSpecMapKeys(integration.Spec.Traits) {
-		if _, err := hash.Write([]byte(name + "[")); err != nil {
-			return "", err
-		}
-		spec, err := json.Marshal(integration.Spec.Traits[name].Configuration)
-		if err != nil {
-			return "", err
-		}
-		trait := make(map[string]interface{})
-		err = json.Unmarshal(spec, &trait)
-		if err != nil {
-			return "", err
-		}
-		for _, prop := range util.SortedMapKeys(trait) {
-			val := trait[prop]
-			if _, err := hash.Write([]byte(fmt.Sprintf("%s=%v,", prop, val))); err != nil {
+	// Calculation logic prior to 1.10.0 (the new Traits API schema) is maintained
+	// in order to keep consistency in the digest calculated from the same set of
+	// Trait configurations for backward compatibility.
+	traitsMap, err := toMap(integration.Spec.Traits)
+	if err != nil {
+		return "", err
+	}
+	for _, name := range sortedTraitsMapKeys(traitsMap) {
+		if name != "addons" {
+			if err := computeForTrait(hash, name, traitsMap[name]); err != nil {
 				return "", err
 			}
-		}
-		if _, err := hash.Write([]byte("]")); err != nil {
-			return "", err
+		} else {
+			// Addons
+			addons := traitsMap["addons"]
+			for _, name := range util.SortedMapKeys(addons) {
+				if addon, ok := addons[name].(map[string]interface{}); ok {
+					if err := computeForTrait(hash, name, addon); err != nil {
+						return "", err
+					}
+				}
+			}
 		}
 	}
 	// Integration traits as annotations
@@ -134,6 +146,53 @@ func ComputeForIntegration(integration *v1.Integration) (string, error) {
 	return digest, nil
 }
 
+func computeForTrait(hash hash.Hash, name string, trait map[string]interface{}) error {
+	if _, err := hash.Write([]byte(name + "[")); err != nil {
+		return err
+	}
+	// hash legacy configuration first
+	if trait["configuration"] != nil {
+		if config, ok := trait["configuration"].(map[string]interface{}); ok {
+			if err := computeForTraitProps(hash, config); err != nil {
+				return err
+			}
+		}
+		delete(trait, "configuration")
+	}
+	if err := computeForTraitProps(hash, trait); err != nil {
+		return err
+	}
+	if _, err := hash.Write([]byte("]")); err != nil {
+		return err
+	}
+
+	return nil
+}
+
+func computeForTraitProps(hash hash.Hash, props map[string]interface{}) error {
+	for _, prop := range util.SortedMapKeys(props) {
+		val := props[prop]
+		if _, err := hash.Write([]byte(fmt.Sprintf("%s=%v,", prop, val))); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func toMap(traits v1.Traits) (map[string]map[string]interface{}, error) {
+	data, err := json.Marshal(traits)
+	if err != nil {
+		return nil, err
+	}
+	traitsMap := make(map[string]map[string]interface{})
+	if err = json.Unmarshal(data, &traitsMap); err != nil {
+		return nil, err
+	}
+
+	return traitsMap, nil
+}
+
 // ComputeForIntegrationKit a digest of the fields that are relevant for the deployment
 // Produces a digest that can be used as docker image tag.
 func ComputeForIntegrationKit(kit *v1.IntegrationKit) (string, error) {
@@ -143,6 +202,10 @@ func ComputeForIntegrationKit(kit *v1.IntegrationKit) (string, error) {
 		return "", err
 	}
 
+	if _, err := hash.Write([]byte(kit.Spec.Image)); err != nil {
+		return "", err
+	}
+
 	for _, item := range kit.Spec.Dependencies {
 		if _, err := hash.Write([]byte(item)); err != nil {
 			return "", err
@@ -232,7 +295,7 @@ func ComputeForSource(s v1.SourceSpec) (string, error) {
 	return digest, nil
 }
 
-func sortedTraitSpecMapKeys(m map[string]v1.TraitSpec) []string {
+func sortedTraitsMapKeys(m map[string]map[string]interface{}) []string {
 	res := make([]string, len(m))
 	i := 0
 	for k := range m {
