@@ -26,6 +26,8 @@ import (
 	"sync/atomic"
 	"time"
 
+	"go.uber.org/multierr"
+
 	klog "github.com/apache/camel-k/pkg/util/log"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -33,7 +35,7 @@ import (
 	"k8s.io/client-go/kubernetes"
 )
 
-// SelectorScraper scrapes all pods with a given selector
+// SelectorScraper scrapes all pods with a given selector.
 type SelectorScraper struct {
 	client               kubernetes.Interface
 	namespace            string
@@ -44,7 +46,7 @@ type SelectorScraper struct {
 	L                    klog.Logger
 }
 
-// NewSelectorScraper creates a new SelectorScraper
+// NewSelectorScraper creates a new SelectorScraper.
 func NewSelectorScraper(client kubernetes.Interface, namespace string, defaultContainerName string, labelSelector string) *SelectorScraper {
 	return &SelectorScraper{
 		client:               client,
@@ -55,14 +57,15 @@ func NewSelectorScraper(client kubernetes.Interface, namespace string, defaultCo
 	}
 }
 
-// Start returns a reader that streams the log of all selected pods
+// Start returns a reader that streams the log of all selected pods.
 func (s *SelectorScraper) Start(ctx context.Context) *bufio.Reader {
 	pipeIn, pipeOut := io.Pipe()
 	bufPipeIn := bufio.NewReader(pipeIn)
 	bufPipeOut := bufio.NewWriter(pipeOut)
 	closeFun := func() error {
-		bufPipeOut.Flush()
-		return pipeOut.Close()
+		return multierr.Append(
+			bufPipeOut.Flush(),
+			pipeOut.Close())
 	}
 	go s.periodicSynchronize(ctx, bufPipeOut, closeFun)
 	return bufPipeIn
@@ -152,7 +155,10 @@ func (s *SelectorScraper) addPodScraper(ctx context.Context, podName string, out
 				s.L.Error(err, "Cannot write to output")
 				return
 			}
-			out.Flush()
+			if err := out.Flush(); err != nil {
+				s.L.Error(err, "Cannot flush output")
+				return
+			}
 			if podCtx.Err() != nil {
 				return
 			}
